Documentation
¶
Index ¶
- func Delete(data []byte, path ...string) (newData []byte)
- func ForEach(data []byte, cb func(key string, value []byte) error, path ...string) (err error)
- func Get(data []byte, path ...string) (value []byte, err error)
- func GetBoolean(data []byte, path ...string) (value bool, err error)
- func GetFloat(data []byte, path ...string) (value float64, err error)
- func GetInt(data []byte, path ...string) (value int64, err error)
- func GetString(data []byte, path ...string) (value string, err error)
- func GetTime(data []byte, path ...string) (value time.Time, err error)
- func GetUnsafeString(data []byte, path ...string) (value string, err error)
- func GetValue(data []byte, path ...string) (value interface{}, err error)
- func Has(data []byte, path ...string) (exists bool)
- func Set(data []byte, value interface{}, path ...string) (newData []byte, err error)
- func SetRawBytes(data []byte, value []byte, path ...string) (newData []byte, err error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ForEach ¶
ForEach iterates over the key-value pairs of the JSON object, invoking a given callback for each such entry
func GetBoolean ¶
GetBoolean fetches the value for the given path as a bool
func GetUnsafeString ¶
GetUnsafeString is like GetString, but unsafe
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.